fin_StockCAGR: Compute the CAGR of a stock

View source: R/financial_functions.R

fin_StockCAGRR Documentation

Compute the CAGR of a stock

Description

fin_StockCAGR uses stock info from Yahoo to work out the CAGR over time.

Usage

fin_StockCAGR(priceSeries, from = "1900-01-01")

Arguments

priceSeries

A price series using yahoo

from

The date in the series to start from (blank = all)

Value

  • value

See Also

  • fin_interest(), fin_NI(), fin_percent()

Other Miscellaneous Functions: deg2rad(), fin_FIF(), fin_JustifiedPE(), fin_NI(), fin_carryCost(), fin_expected(), fin_interest(), fin_net_present_value(), fin_option(), fin_percent(), fin_ticker(), fin_valuation(), rad2deg(), umxBrownie()

Examples

## Not run: 
libs(c("quantmod", "ggplot2", "scales", "lubridate"))
getSymbols(c("NVDA"), from = "2010-01-01", to = Sys.Date())
startDate = "2016-01-01"
nvdaCagr = fin_StockCAGR(NVDA, startDate)

## End(Not run)

umx documentation built on May 18, 2026, 5:07 p.m.