fin_carryCost: Work the carry cost of a house

View source: R/financial_functions.R

fin_carryCostR Documentation

Work the carry cost of a house

Description

fin_carryCost uses the purchase price, holding expenses, appreciation, and opportunity cost to compute a carrying cost for a house purchase.

Usage

fin_carryCost(
  property_cost,
  appreciation = 0.02,
  QQQ = 0.14,
  rent_saved = 0.04,
  interest = 0.06,
  rates = 5000,
  insurance = 2000,
  maintenance = 0.015,
  years = 5
)

Arguments

property_cost

Purchase price

appreciation

rate of property increase

QQQ

Opportunity cost of leaving money in the markets

rent_saved

But now you have to rent somewhere

interest

Cost of borrowing

rates

Council

insurance

The cost of property owners insurance

maintenance

New kitchen roof etc.

years

Holding time.

Value

  • value

See Also

  • fin_interest(), fin_NI(), fin_percent()

Other Miscellaneous Functions: deg2rad(), fin_FIF(), fin_JustifiedPE(), fin_NI(), fin_StockCAGR(), fin_expected(), fin_interest(), fin_net_present_value(), fin_option(), fin_percent(), fin_ticker(), fin_valuation(), rad2deg(), umxBrownie()

Examples

fin_carryCost(property_cost=1.2e6)
fin_carryCost(property_cost=1.1e6, appreciation = .035, QQQ=.15, years=10)


umx documentation built on May 18, 2026, 5:07 p.m.