Learn R Programming

umx (version 1.2.5)

umxHetCor: umxHetCor

Description

umxHetCor Helper to return just the correlations from John Fox's polycor::hetcor function

Usage

umxHetCor(data, ML = FALSE, use = c("pairwise.complete.obs",
  "complete.obs"), treatAllAsFactor = FALSE, verbose = FALSE)

Arguments

data
A data.frame of columns for which to compute heterochoric correlations
ML
Whether to use Maximum likelihood computation of correlations (default = FALSE)
use
How to handle missing data: "complete.obs" (Default), "pairwise.complete.obs"
treatAllAsFactor
Whether to treat all columns as factors, whether they are or not.
verbose
How much to tell the user about what was done.

Value

  • - A matrix of correlations

References

-

See Also

Other Data Functions: umxCovData, umxFactor, umxPadAndPruneForDefVars, umx_as_numeric, umx_cont_2_ordinal, umx_cov2raw, umx_fake_data, umx_lower2full, umx_make_bin_cont_pair_data, umx_merge_CIs, umx_read_lower, umx_reorder, umx_residualize, umx_round, umx_scale_wide_twin_data, umx_scale, umx_swap_a_block, umx

Examples

Run this code
umxHetCor(mtcars[,c("mpg", "am")])
umxHetCor(mtcars[,c("mpg", "am")], treatAllAsFactor = FALSE, verbose = TRUE)

Run the code above in your browser using DataLab