Learn R Programming

umx (version 1.2.5)

umxPlotIP: umxPlotIP

Description

Make a graphical display of an Independent Pathway model

Usage

umxPlotIP(x = NA, file = "name", digits = 2, showMeans = FALSE,
  std = TRUE, ...)

Arguments

x
The umxIP model to plot
file
The name of the dot file to write: NA = none; "name" = use the name of the model
digits
How many decimals to include in path loadings (defaults to 2)
showMeans
Whether to show means paths (defaults to FALSE)
std
whether to standardize the model (defaults to TRUE)
...
Optional additional parameters

Value

  • - optionally return the dot code

References

- http://tbates.github.io

See Also

- plot(), umxSummary()

Examples

Run this code
plot(model)
umxPlotIP(model, file = NA)

Run the code above in your browser using DataLab