Learn R Programming

umx (version 1.2.5)

umxUnexplainedCausalNexus: umxUnexplainedCausalNexus

Description

umxUnexplainedCausalNexus report the effect of a change (delta) in a variable (from) on an output (to)

Usage

umxUnexplainedCausalNexus(from, delta, to, model)

Arguments

from
A variable in the model that you want to imput the effect of a change
delta
A the amount to simulate changing "from" by.
to
The dependent variable that you want to watch changing
model
The model containing from and to

References

- http://www.github.com/tbates/umx/

See Also

- umxRun, mxCompare

Other Modify or Compare Models: umxAdd1, umxDrop1, umxEquate, umxFixAll, umxGetParameters, umxMI, umxSetParameters, umx

Examples

Run this code
umxUnexplainedCausalNexus(from="yrsEd", delta = .5, to = "income35", model)

Run the code above in your browser using DataLab