Learn R Programming

umx (version 1.2.5)

umx_RAM_ordinal_objective: umx_RAM_ordinal_objective

Description

umx_RAM_ordinal_objective builds an appropriate thresholds matrix It also sets latent means and variances to 0 and 1 respectively.

Usage

umx_RAM_ordinal_objective(df, deviationBased = TRUE, droplevels = TRUE,
  verbose = FALSE)

Arguments

df
Dataframe to make a threshold matrix for
deviationBased
whether to use the deviation system to ensure order thresholds (default = TRUE)
droplevels
whether to also drop unused levels (default = TRUE)
verbose
whether to say what the function is doing (default = FALSE)

Value

Details

TODO: more detail about what we are doing here

References

- http://www.github.com/tbates/umx

See Also

Other zAdvanced Helpers: umx_standardize_ACEcov, umx_standardize_ACE, umx_standardize_CP, umx_standardize_IP, umx

Examples

Run this code
model = umx_RAM_ordinal_objective(model)

Run the code above in your browser using DataLab