Learn R Programming

umx (version 1.2.5)

umx_find_object: umx_find_object

Description

Find objects a certain class, whose name matches a search string. The string (pattern) is grep-enabled, so you can match wild-cards

Usage

umx_find_object(pattern = ".*", requiredClass = "MxModel")

Arguments

pattern
the pattern that matching objects must contain
requiredClass
the class of object that will be matched

Value

  • - a list of objects matching the class and name

References

-

See Also

Other Utility Functions: qm, umx_grep, umx_msg, umx_names, umx_paste_names, umx_pb_note, umx_print, umx_rename, umx

Examples

Run this code
umx_find_object("^m[0-9]") # mxModels beginning "m1" etc.
umx_find_object("", "MxModel") # all MxModels

Run the code above in your browser using DataLab