Learn R Programming

umx (version 1.2.5)

umx_is_MxModel: umx_is_MxModel

Description

Utility function returning a binary answer to the question "Is this an OpenMx model?"

Usage

umx_is_MxModel(obj)

Arguments

obj
an object to be tested to see if it is an OpenMx mxModel

Value

  • - Boolean

References

- http://www.github.com/tbates/umx

See Also

Other Test: umx_check_OS, umx_check_model, umx_check_names, umx_check_parallel, umx_check, umx_has_CIs, umx_has_been_run, umx_has_means, umx_has_square_brackets, umx_is_MxMatrix, umx_is_RAM, umx_is_cov, umx_is_endogenous, umx_is_exogenous, umx_is_ordered

Examples

Run this code
m1 = mxModel("test")
if(umx_is_MxModel(m1)){
	message("nice OpenMx model!")
}

Run the code above in your browser using DataLab