umx_merge_CIs(m1, m2)
# TODO remove duplicates...
# TODO (check they are the same as well!)
# TODO Support arbitrarily long list of input models with ...
# TODO check the models are the same, with same fit
# TODO check the models have CIsRun the code above in your browser using DataLab