Use the pushbullet service to push a note. You can also initialise this
service by providing your autho_key one time
Usage
umx_pb_note(title = "test", body = "default body", auth_key = NA)
Arguments
title
of the note
body
of the note
auth_key
optional authkey (default = NA, set to value of your key to store key.
Details
If you supply auth_key, It will be writen to "~/.pushbulletkey"
umx_pb_note(auth_key="mykeystring")
once it exists there, you dont need to store it in code, so code is sharable.
You can get your authaurization key at https://www.pushbullet.com in
the "account" section.
Note: You can show the existing stored key using "GET"