View source: R/financial_functions.R
| fin_FIF | R Documentation |
NZ FIF Tax Offset & NAV Neutrality Calculator
fin_FIF(portfolioValue, marginRate, expectedReturn, taxRate, fifRate = 0.05)
portfolioValue |
Total opening value of the portfolio on April 1st. |
marginRate |
The annual interest rate on the IBKR margin loan (e.g., 0.06). |
expectedReturn |
The expected annual growth of the asset (e.g., 0.11 for QQQ). |
taxRate |
The user's marginal tax rate (e.g., 0.39 or .3 (blended)). |
fifRate |
The FIF deemed rate of return (standard is 0.05). |
A ggplot object showing the net impact across LTV ratios.
fin_interest(), fin_NI(), fin_percent()
Other Miscellaneous Functions:
deg2rad(),
fin_JustifiedPE(),
fin_NI(),
fin_StockCAGR(),
fin_carryCost(),
fin_expected(),
fin_interest(),
fin_net_present_value(),
fin_option(),
fin_percent(),
fin_ticker(),
fin_valuation(),
rad2deg(),
umxBrownie()
# Example Usage:
# 2026 Strategy: $500k Portfolio, 6.5% IBKR Rate, 12% Expected Return, 39% Tax
fin_FIF(portfolioValue = .5e6, marginRate = 0.065, expectedReturn = 0.12, taxRate = 0.39)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.