View source: R/financial_functions.R
| fin_StockCAGR | R Documentation |
fin_StockCAGR uses stock info from Yahoo to work out the CAGR over time.
fin_StockCAGR(priceSeries, from = "1900-01-01")
priceSeries |
A price series using yahoo |
from |
The date in the series to start from (blank = all) |
value
fin_interest(), fin_NI(), fin_percent()
Other Miscellaneous Functions:
deg2rad(),
fin_FIF(),
fin_JustifiedPE(),
fin_NI(),
fin_carryCost(),
fin_expected(),
fin_interest(),
fin_net_present_value(),
fin_option(),
fin_percent(),
fin_ticker(),
fin_valuation(),
rad2deg(),
umxBrownie()
## Not run:
libs(c("quantmod", "ggplot2", "scales", "lubridate"))
getSymbols(c("NVDA"), from = "2010-01-01", to = Sys.Date())
startDate = "2016-01-01"
nvdaCagr = fin_StockCAGR(NVDA, startDate)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.